==> openshift-model-6.3.0-sources.jar: io/fabric8/openshift/api/model/RollingDeploymentStrategyParamsFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RollingDeploymentStrategyParamsFluent<A extends RollingDeploymentStrategyParamsFluent<A>> extends Fluent<A>{
  public Long getIntervalSeconds();
  public A withIntervalSeconds(Long intervalSeconds);
  public Boolean hasIntervalSeconds();
  
  /**
   * This method has been deprecated, please use method buildMaxSurge instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxSurge();
  public IntOrString buildMaxSurge();
  public A withMaxSurge(IntOrString maxSurge);
  public Boolean hasMaxSurge();
  public A withNewMaxSurge(Object value);
  public RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> withNewMaxSurge();
  public RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> withNewMaxSurgeLike(IntOrString item);
  public RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editMaxSurge();
  public RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editOrNewMaxSurge();
  public RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editOrNewMaxSurgeLike(IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable();
  public IntOrString buildMaxUnavailable();
  public A withMaxUnavailable(IntOrString maxUnavailable);
  public Boolean hasMaxUnavailable();
  public A withNewMaxUnavailable(Object value);
  public RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> withNewMaxUnavailable();
  public RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item);
  public RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editMaxUnavailable();
  public RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable();
  public RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildPost instead.
   * @return The buildable object.
   */
  @Deprecated
  public LifecycleHook getPost();
  public LifecycleHook buildPost();
  public A withPost(LifecycleHook post);
  public Boolean hasPost();
  public RollingDeploymentStrategyParamsFluent.PostNested<A> withNewPost();
  public RollingDeploymentStrategyParamsFluent.PostNested<A> withNewPostLike(LifecycleHook item);
  public RollingDeploymentStrategyParamsFluent.PostNested<A> editPost();
  public RollingDeploymentStrategyParamsFluent.PostNested<A> editOrNewPost();
  public RollingDeploymentStrategyParamsFluent.PostNested<A> editOrNewPostLike(LifecycleHook item);
  
  /**
   * This method has been deprecated, please use method buildPre instead.
   * @return The buildable object.
   */
  @Deprecated
  public LifecycleHook getPre();
  public LifecycleHook buildPre();
  public A withPre(LifecycleHook pre);
  public Boolean hasPre();
  public RollingDeploymentStrategyParamsFluent.PreNested<A> withNewPre();
  public RollingDeploymentStrategyParamsFluent.PreNested<A> withNewPreLike(LifecycleHook item);
  public RollingDeploymentStrategyParamsFluent.PreNested<A> editPre();
  public RollingDeploymentStrategyParamsFluent.PreNested<A> editOrNewPre();
  public RollingDeploymentStrategyParamsFluent.PreNested<A> editOrNewPreLike(LifecycleHook item);
  public Long getTimeoutSeconds();
  public A withTimeoutSeconds(Long timeoutSeconds);
  public Boolean hasTimeoutSeconds();
  public Long getUpdatePeriodSeconds();
  public A withUpdatePeriodSeconds(Long updatePeriodSeconds);
  public Boolean hasUpdatePeriodSeconds();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MaxSurgeNested<N> extends Nested<N>,IntOrStringFluent<RollingDeploymentStrategyParamsFluent.MaxSurgeNested<N>>{
    public N and();
    public N endMaxSurge();
    
  }
  public interface MaxUnavailableNested<N> extends Nested<N>,IntOrStringFluent<RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<N>>{
    public N and();
    public N endMaxUnavailable();
    
  }
  public interface PostNested<N> extends Nested<N>,LifecycleHookFluent<RollingDeploymentStrategyParamsFluent.PostNested<N>>{
    public N and();
    public N endPost();
    
  }
  public interface PreNested<N> extends Nested<N>,LifecycleHookFluent<RollingDeploymentStrategyParamsFluent.PreNested<N>>{
    public N and();
    public N endPre();
    
  }
  
}

==> openshift-model-6.7.1-sources.jar: io/fabric8/openshift/api/model/RollingDeploymentStrategyParamsFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RollingDeploymentStrategyParamsFluent<A extends RollingDeploymentStrategyParamsFluent<A>> extends Fluent<A>{
  public Long getIntervalSeconds();
  public A withIntervalSeconds(Long intervalSeconds);
  public Boolean hasIntervalSeconds();
  
  /**
   * This method has been deprecated, please use method buildMaxSurge instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxSurge();
  public IntOrString buildMaxSurge();
  public A withMaxSurge(IntOrString maxSurge);
  public Boolean hasMaxSurge();
  public A withNewMaxSurge(Object value);
  public RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> withNewMaxSurge();
  public RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> withNewMaxSurgeLike(IntOrString item);
  public RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editMaxSurge();
  public RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editOrNewMaxSurge();
  public RollingDeploymentStrategyParamsFluent.MaxSurgeNested<A> editOrNewMaxSurgeLike(IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable();
  public IntOrString buildMaxUnavailable();
  public A withMaxUnavailable(IntOrString maxUnavailable);
  public Boolean hasMaxUnavailable();
  public A withNewMaxUnavailable(Object value);
  public RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> withNewMaxUnavailable();
  public RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item);
  public RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editMaxUnavailable();
  public RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable();
  public RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item);
  
  /**
   * This method has been deprecated, please use method buildPost instead.
   * @return The buildable object.
   */
  @Deprecated
  public LifecycleHook getPost();
  public LifecycleHook buildPost();
  public A withPost(LifecycleHook post);
  public Boolean hasPost();
  public RollingDeploymentStrategyParamsFluent.PostNested<A> withNewPost();
  public RollingDeploymentStrategyParamsFluent.PostNested<A> withNewPostLike(LifecycleHook item);
  public RollingDeploymentStrategyParamsFluent.PostNested<A> editPost();
  public RollingDeploymentStrategyParamsFluent.PostNested<A> editOrNewPost();
  public RollingDeploymentStrategyParamsFluent.PostNested<A> editOrNewPostLike(LifecycleHook item);
  
  /**
   * This method has been deprecated, please use method buildPre instead.
   * @return The buildable object.
   */
  @Deprecated
  public LifecycleHook getPre();
  public LifecycleHook buildPre();
  public A withPre(LifecycleHook pre);
  public Boolean hasPre();
  public RollingDeploymentStrategyParamsFluent.PreNested<A> withNewPre();
  public RollingDeploymentStrategyParamsFluent.PreNested<A> withNewPreLike(LifecycleHook item);
  public RollingDeploymentStrategyParamsFluent.PreNested<A> editPre();
  public RollingDeploymentStrategyParamsFluent.PreNested<A> editOrNewPre();
  public RollingDeploymentStrategyParamsFluent.PreNested<A> editOrNewPreLike(LifecycleHook item);
  public Long getTimeoutSeconds();
  public A withTimeoutSeconds(Long timeoutSeconds);
  public Boolean hasTimeoutSeconds();
  public Long getUpdatePeriodSeconds();
  public A withUpdatePeriodSeconds(Long updatePeriodSeconds);
  public Boolean hasUpdatePeriodSeconds();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MaxSurgeNested<N> extends Nested<N>,IntOrStringFluent<RollingDeploymentStrategyParamsFluent.MaxSurgeNested<N>>{
    public N and();
    public N endMaxSurge();
    
  }
  public interface MaxUnavailableNested<N> extends Nested<N>,IntOrStringFluent<RollingDeploymentStrategyParamsFluent.MaxUnavailableNested<N>>{
    public N and();
    public N endMaxUnavailable();
    
  }
  public interface PostNested<N> extends Nested<N>,LifecycleHookFluent<RollingDeploymentStrategyParamsFluent.PostNested<N>>{
    public N and();
    public N endPost();
    
  }
  public interface PreNested<N> extends Nested<N>,LifecycleHookFluent<RollingDeploymentStrategyParamsFluent.PreNested<N>>{
    public N and();
    public N endPre();
    
  }
  
}
